import React from 'react';
import { Icon, Button, Input, Select, Spin, Table, Switch, message, DatePicker, Modal } from 'antd';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';
import moment from 'moment';
import './techAchievement.less';
import TechAchievementDesc from './techAchievementDesc.jsx';
import { achievementCategoryList, techAuditStatusList } from '../../dataDic.js';
import { getAchievementCategory, getTechAuditStatus } from '../../tools.js';

const AchievementList = React.createClass({
    loadData(pageNo) {
        this.state.data = [];
        this.setState({
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + '/api/user/achievement/list',
            data: {
                pageNo: pageNo || 1,
                pageSize: this.state.pagination.pageSize,
                serialNumber: this.state.serialNumber, //编号
                name: this.state.name, //名称
                keyword: this.state.keyword, // 关键词
                category: this.state.category, //类型(0--专利, 2--软著, 3--项目, 4--版权, 5--工业设计, 6--配方, 7--非标)
                releaseDateStartDate: this.state.releaseDate[0],
                releaseDateEndDate: this.state.releaseDate[1],
                releaseStatus: this.state.releaseStatus ? Number(this.state.releaseStatus) : undefined, //是否发布(0--未发布,1--已发布)
                auditStatus: this.state.auditStatus
            },
            success: function (data) {
                let theArr = [];
                if (!data.data || !data.data.list) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else {
                    for (let i = 0; i < data.data.list.length; i++) {
                        let thisdata = data.data.list[i];
                        theArr.push({
                            key: i,
                            id: thisdata.id,
                            serialNumber: thisdata.serialNumber,
                            dataCategory: thisdata.dataCategory,
                            name: thisdata.name,
                            keyword: thisdata.keyword,
                            category: thisdata.category,
                            ownerName: thisdata.ownerName,
                            ownerType: thisdata.ownerType,
                            ownerMobile: thisdata.ownerMobile,
                            status: thisdata.status,
                            releaseDate: thisdata.releaseDate,
                            releaseDateFormattedDate: thisdata.releaseDateFormattedDate,
                            auditStatus: thisdata.auditStatus
                        });
                    };
                }
                this.state.pagination.current = data.data.pageNo;
                this.state.pagination.total = data.data.totalCount;
                this.setState({
                    dataSource: theArr,
                    pagination: this.state.pagination
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            searchMore: true,
            validityPeriodDate: [],
            releaseDate: [],
            selectedRowKeys: [],
            selectedRows: [],
            loading: false,
            pagination: {
                defaultCurrent: 1,
                defaultPageSize: 10,
                showQuickJumper: true,
                pageSize: 10,
                onChange: function (page) {
                    this.loadData(page);
                }.bind(this),
                showTotal: function (total) {
                    return '共' + total + '条数据';
                }
            },
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber',
                }, {
                    title: '名称',
                    dataIndex: 'name',
                    key: 'name',
                }, {
                    title: '关键字',
                    dataIndex: 'keyword',
                    key: 'keyword',
                }, {
                    title: '类型',
                    dataIndex: 'category',
                    key: 'category',
                    render: text => { return getAchievementCategory(text); }
                }, {
                    title: '审核状态',
                    dataIndex: 'auditStatus',
                    key: 'auditStatus',
                    render: text => { return getTechAuditStatus(text) }
                }, {
                    title: '发布时间',
                    dataIndex: 'releaseDateFormattedDate',
                    key: 'releaseDateFormattedDate',
                }
            ],
            dataSource: [],
            searchTime: [,]
        };
    },
    componentWillMount() {
        let theArr = [];
        achievementCategoryList.map(function (item) {
            theArr.push(
                <Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
            )
        });
        let auditArr = [];
        techAuditStatusList.map(function (item) {
            auditArr.push(
                <Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
            )
        });
        this.state.achievementCategoryOption = theArr;
        this.state.auditStatusOption = auditArr;
        this.loadData();
    },
    tableRowClick(record, index) {
        this.state.RowData = record;
        this.setState({
            showDesc: true
        });
    },
    delectRow() {
        let deletedIds = [];
        for (let idx = 0; idx < this.state.selectedRows.length; idx++) {
            let rowItem = this.state.selectedRows[idx];
            if (rowItem.id) {
                deletedIds.push(rowItem.id)
            };
        };
        this.setState({
            selectedRowKeys: [],
            loading: deletedIds.length > 0
        });
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/user/achievement/delete",
            data: {
                ids: deletedIds
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('删除成功！');
                this.setState({
                    loading: false,
                });
            } else {
                message.warning(data.error[0].message);
            };
            this.loadData();
        }.bind(this));
    },
    addClick() {
        this.state.RowData = {};
        this.setState({
            showDesc: true
        });
    },
    closeDesc(e, s) {
        this.state.showDesc = e;
        if (s) {
            this.loadData();
        };
    },
    search() {
        this.loadData();
    },
    reset() {
        this.state.serialNumber = undefined;
        this.state.name = undefined;
        this.state.keyword = undefined;
        this.state.category = undefined;
        this.state.ownerType = undefined;
        this.state.releaseStatus = undefined;
        this.state.releaseDate = [];
        this.state.auditStatus = undefined;
        this.loadData();
    },
    searchSwitch() {
        this.setState({
            searchMore: !this.state.searchMore
        });
    },
    downLoadFile() {
        window.open(globalConfig.context + '/api/user/achievement/downloadTemplate?sign=achievement_template')
    },
    render() {
        const rowSelection = {
            selectedRowKeys: this.state.selectedRowKeys,
            onChange: (selectedRowKeys, selectedRows) => {
                this.setState({
                    selectedRows: selectedRows.slice(-1),
                    selectedRowKeys: selectedRowKeys.slice(-1)
                });
            }
        };
        const hasSelected = this.state.selectedRowKeys.length > 0;
        const { RangePicker } = DatePicker;
        return (
            <div className="user-content" >
                <div className="content-title">
                    <span>科技成果管理</span>
                    <div className="patent-addNew">
                        <Button onClick={this.downLoadFile}>下载批量导入模板</Button>
                        <Button className="addButton" type="primary" onClick={this.addClick}>发布成果<Icon type="plus" /></Button>
                    </div>
                </div>
                <div className="user-search">
                    <Input placeholder="编号"
                        value={this.state.serialNumber}
                        onChange={(e) => { this.setState({ serialNumber: e.target.value }); }} />
                    <Input placeholder="名称"
                        value={this.state.name}
                        onChange={(e) => { this.setState({ name: e.target.value }); }} />
                    <Input placeholder="关键字"
                        value={this.state.keyword}
                        onChange={(e) => { this.setState({ keyword: e.target.value }); }} />
                    <Select placeholder="选择类型" style={{ width: 160 }}
                        value={this.state.category}
                        onChange={(e) => { this.setState({ category: e }) }}>
                        {this.state.achievementCategoryOption}
                    </Select>
                    <Select placeholder="选择审核状态"
                        style={{ width: 160 }}
                        value={this.state.auditStatus}
                        onChange={(e) => { this.setState({ auditStatus: e }) }}>
                        {this.state.auditStatusOption}
                    </Select>
                    <Select placeholder="选择是否发布" style={{ width: 120 }}
                        value={this.state.releaseStatus}
                        onChange={(e) => { this.setState({ releaseStatus: e }) }}>
                        <Select.Option value="0" >未发布</Select.Option>
                        <Select.Option value="1" >已发布</Select.Option>
                    </Select>
                    <Button type="primary" onClick={this.search}>搜索</Button>
                    <Button onClick={this.reset}>重置</Button>
                    <Button style={{ background: "#3fcf9e", border: "none", color: "#fff" }}
                        disabled={!hasSelected}
                        onClick={this.delectRow}>删除<Icon type="minus" /></Button>
                    <span>更多搜索<Switch defaultChecked={false} onChange={this.searchSwitch} /></span>
                    <div className="search-more" style={this.state.searchMore ? { display: 'none' } : {}}>
                        <span>发布时间 :</span>
                        <RangePicker
                            value={[this.state.releaseDate[0] ? moment(this.state.releaseDate[0]) : null,
                            this.state.releaseDate[1] ? moment(this.state.releaseDate[1]) : null]}
                            onChange={(data, dataString) => { this.setState({ releaseDate: dataString }); }} />
                    </div>
                </div>
                <div className="patent-table">
                    <Spin spinning={this.state.loading}>
                        <Table columns={this.state.columns}
                            dataSource={this.state.dataSource}
                            rowSelection={rowSelection}
                            pagination={this.state.pagination}
                            onRowClick={this.tableRowClick} />
                    </Spin>
                </div>
                <TechAchievementDesc
                    data={this.state.RowData}
                    achievementCategoryOption={this.state.achievementCategoryOption}
                    showDesc={this.state.showDesc}
                    closeDesc={this.closeDesc} />
            </div >
        );
    }
});

export default AchievementList;